@@ -17,6 +17,15 @@
 extern "C" {
 #endif
 
+/*
+ * use those to be sure nothing nasty will happen if
+ * your library and includes mismatch
+ */
+extern void xmlCheckVersion(int version);
+#define LIBXML_VERSION_NUMBER 10808
+#define LIBXML_TEST_VERSION xmlCheckVersion(LIBXML_VERSION_NUMBER);
+
+
 /*
  * The different element types carried by an XML tree
  *
@@ -310,6 +319,14 @@ struct _xmlDoc {
     void           *refs;       /* Hash table for IDREFs attributes if any */
 };
 
+/*
+ * Compatibility naming layer with libxml1
+ */
+#ifndef xmlChildrenNode
+#define xmlChildrenNode childs
+#define xmlRootNode root
+#endif
+
 /*
  * Variables.
  */
